@@ -177,7 +177,10 @@ class Label:
     @text.setter
     def text(self,text):
         self._text=text 
-        self.shown_text=self._text    
+        if len(self._text)>100:
+            self.shown_text=self._text[:100]
+        else:
+            self.shown_text=self._text
     
         self.text_length=self.myfont.size(self.shown_text)[0]
         
@@ -334,6 +337,7 @@ def refresh(pgwidgets):
 class CollidableComponent(abc.ABC):    
     def is_collided(self,rects):
         is_collided_at_least_once=False
+        collision_entry = None
         for i in range(len(rects)):
             if rects[i]!=self:
                 
@@ -360,11 +364,16 @@ class CollidableComponent(abc.ABC):
                     
                 if collision:
                     is_collided_at_least_once=True
+                    collision_entry = rects[i]
                     #print("collision function")
                     self.collision_function(rects[i])
                     
         if not is_collided_at_least_once:
             self.non_collision_function()
+            
+        return(is_collided_at_least_once,collision_entry)
+    
+    
     
     def collision_function(self,target_rect):
         pass
@@ -722,8 +731,8 @@ class Grid(ScrollableComponent):
                 label.draw(screen)
         
         
-        
-        pygame.draw.rect(screen,(130,130,130),[self.pos[0]-1,self.pos[1]-1]+self.table_size,self.frame_border_width)
+        if self.frame_border_width!=-1:
+            pygame.draw.rect(screen,(130,130,130),[self.pos[0]-1,self.pos[1]-1]+self.table_size,self.frame_border_width)
         
         #selected cell
         
@@ -1117,7 +1126,7 @@ class Button(DraggableRect):
         self.hover_color=hover_color
         self.hover_label_color=hover_label_color
         
-        
+
         
     def draw(self,screen):
         #print(self.label.color)
@@ -1381,6 +1390,7 @@ class Entry(DraggableRect):
             self._asterisk_text="".join(len(self._text)*["*"])
             self.labels[0].text = self._asterisk_text
         else:
+            
             self.labels[0].text = text
         
 
@@ -1406,6 +1416,10 @@ class Entry(DraggableRect):
         
         
 
+
+
+
+
     
 
 
